=== modified file 'Makefile'
--- Makefile	2014-03-12 17:49:46 +0000
+++ Makefile	2014-05-08 18:59:09 +0000
@@ -1,6 +1,6 @@
 ## Makefile for the TAPAAL project (Mac)
 
-#Copyright (c) 2009, Kenneth Yrke Jørgensen <kyrke@cs.aau.dk>
+#Copyright (c) 2009-2011, Kenneth Yrke Jørgensen <kyrke@cs.aau.dk>
 #All rights reserved.
 #
 #Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
@@ -13,21 +13,38 @@
 #
 
 # Location of trees.
-SOURCE_DIR  := src 
+SOURCE_DIR  := src
+RESOURCE_DIR := $(SOURCE_DIR)/resources
 OUTPUT_DIR  := classes
 
+RELEASE_DIR := release-version
+RELEASEJAR_DIR := releasejar-version
 
 PROJECTNAME := TAPAAL
 
-JAVA_HOME := /System/Library/Java/JavaVirtualMachines/1.6.0.jdk/Contents/Home
+JAR_DIR := buildjar
+JAR_FILE := $(JAR_DIR)/tapaal.jar
+
+#Set location of java home
+#ifeq (exists, $(shell [ -d /System/Library/Java/JavaVirtualMachines/1.6.0.jdk/Contents/Home ]  && echo exists ))
+#	JAVA_HOME := /System/Library/Java/JavaVirtualMachines/1.6.0.jdk/Contents/Home
+#endif
+
+#ifeq (exists, $(shell [ -d /Library/Java/JavaVirtualMachines/jdk1.7.0_21.jdk/Contents/Home ]  && echo exists ))
+#	JAVA_HOME := /Library/Java/JavaVirtualMachines/jdk1.7.0_21.jdk/Contents/Home 
+JAVA_HOME := $(/usr/libexec/java_home)
+#endif
+
 JAVA_LIB  := $(JAVA_HOME)/lib
 
-
-DEPEND := libs/jpowergraph-0.2-common.jar:libs/jpowergraph-0.2-swing.jar:libs/gtkjfilechooser.jar:libs/gtkjfilechooser.jar:libs/GOLDEngine.jar:libs/commons-cli-1.2.jar:libs/AppleJavaExtensions.jar:
-
-
-JFLAGS      := -sourcepath $(SOURCE_DIR) \
-		-cp $(DEPEND)
+DEPEND_DIR := libs
+DEPEND := $(DEPEND_DIR)/\*
+
+JFLAGS      := -source 1.6 -target 1.6 \
+              -sourcepath $(SOURCE_DIR) -cp $(DEPEND)
+# -bootclasspath /Library/Java/JavaVirtualMachines/jdk1.7.0_21.jdk/Contents/Home/jre/lib/rt.jar \
+#/System/Library/Java/JavaVirtualMachines/1.6.0.jdk/Contents/Classes/classes.jar -extdirs " " \
+
 
 # Unix tools
 AWK         := awk
@@ -39,10 +56,13 @@
 
 # Java tools
 
-JAVA        := $(JAVA_HOME)/bin/java
-JAVAC       := $(JAVA_HOME)/bin/javac
-
-default: RunGui.class
+JAVA        :=  java
+JAVAC       :=  javac
+JAR       := jar
+
+	MAINCLASS := $(SOURCE_DIR)/TAPAAL
+default: ${MAINCLASS}.class
+
 
 %.class : %.java
 	$(JAVAC) $(JFLAGS) $*.java
@@ -52,22 +72,44 @@
 	$(FIND) $(SOURCE_DIR) -name '*.java' > $@
 	sed -ie 's#\.java#\.class#' $@
 
-
-buildsrc: clean
-	tar czf tapaal_version.orig.tar.gz Makefile pipe/ jpowergraph-0.2-common.jar jpowergraph-0.2-swing.jar gtkjfilechooser.jar schema/ jpowergraph/ java_cup/ jama/ Images/ expressions/  Example\ nets/ Docs/ dk/ cfg/ run-unix/  xslt/ RunGui.java
-
 .PHONY : clean
 clean:
 	@rm -f ${all_javas}
 	@find . -name '*.class' | xargs -L 1 rm -f
 	@rm -f tapaal_version.orig.tar.gz
-	@rm -rf ${OUTPUT_DIR}
+	@rm -rf '${OUTPUT_DIR}'
+	@rm -rf '$(RELEASE_DIR)'
+	@rm -rf '$(JAR_DIR)'
+	@rm -rf '$(RELEASEJAR_DIR)'
+	@rm -rf 'bin' # Remove the Eclipse build files
+
 
 release: clean 
 	@mkdir $(OUTPUT_DIR)
-	$(JAVAC) $(JFLAGS) -d $(OUTPUT_DIR)/ src/TAPAAL.java
-
+	@mkdir $(RELEASE_DIR)
+	$(JAVAC) $(JFLAGS) -d $(OUTPUT_DIR)/ '$(MAINCLASS).java' -encoding UTF8
+	cp -R $(OUTPUT_DIR)/* '$(RELEASE_DIR)'
+	cp -R '$(RESOURCE_DIR)' '$(RELEASE_DIR)'
+	cp -R $(DEPEND_DIR)/* '$(RELEASE_DIR)'
+
+releasejar: clean jar
+	@mkdir $(RELEASEJAR_DIR)
+	cp '$(JAR_FILE)' '$(RELEASEJAR_DIR)'
+	cp -R $(DEPEND_DIR)/* '$(RELEASEJAR_DIR)'
+
+
+jar: release 
+	@mkdir $(JAR_DIR)
+	$(JAR) -cfe $(JAR_FILE) TAPAAL -C $(RELEASE_DIR) . 
 
 #Remove BYTE ORDER MARK
 removeBOM:  
 	sed -i '1 s/^\xef\xbb\xbf//' $*.java
+
+TOOLS_DIR := tools
+
+install: release
+	mkdir -p $(DESTDIR)/usr/lib/tapaal/
+	cp -R $(CURDIR)/$(RELEASE_DIR)/* $(DESTDIR)/usr/lib/tapaal/
+	cp -R $(CURDIR)/$(TOOLS_DIR)/run-unix $(DESTDIR)/usr/bin/tapaal
+

